@@ -40,7 +40,7 @@ import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 
 /**
- * Class loader able to load classes and DLLs with a higher priority from a given set of JARs. 
+ * Class loader able to load classes and DLLs with a higher priority from a given set of JARs.
  * Its bytecode is Java 1.1 compatible to be loadable by old JVMs.
  * @author Emmanuel Puybaret
  */
@@ -53,46 +53,46 @@ public class ExtensionsClassLoader extends ClassLoader {
 
   /**
    * Creates a class loader. It will consider JARs and DLLs of <code>extensionJarsAndDlls</code> accessed as resources
-   * as classpath and libclasspath elements with a higher priority than the ones of default classpath, 
+   * as classpath and libclasspath elements with a higher priority than the ones of default classpath,
    * and will load itself all the classes belonging to packages of <code>applicationPackages</code>.
    * No cache will be used.
    */
-  public ExtensionsClassLoader(ClassLoader parent, 
-                               ProtectionDomain protectionDomain, 
+  public ExtensionsClassLoader(ClassLoader parent,
+                               ProtectionDomain protectionDomain,
                                String [] extensionJarsAndDlls,
                                String [] applicationPackages) {
     this(parent, protectionDomain, extensionJarsAndDlls, new URL [0], applicationPackages, null, null);
   }
-  
+
   /**
    * Creates a class loader. It will consider JARs and DLLs of <code>extensionJarAndDllResources</code>
-   * and <code>extensionJarAndDllUrls</code> as classpath and libclasspath elements with a higher priority 
-   * than the ones of default classpath, and will load itself all the classes belonging to packages of 
+   * and <code>extensionJarAndDllUrls</code> as classpath and libclasspath elements with a higher priority
+   * than the ones of default classpath, and will load itself all the classes belonging to packages of
    * <code>applicationPackages</code>.<br>
-   * Copies of <code>extensionJarAndDllResources</code> and <code>extensionJarAndDllUrls</code> will be stored 
+   * Copies of <code>extensionJarAndDllResources</code> and <code>extensionJarAndDllUrls</code> will be stored
    * in the given cache folder if possible, each file being prefixed by <code>cachedFilesPrefix</code>.
    */
-  public ExtensionsClassLoader(ClassLoader parent, 
-                               ProtectionDomain protectionDomain, 
+  public ExtensionsClassLoader(ClassLoader parent,
+                               ProtectionDomain protectionDomain,
                                String [] extensionJarAndDllResources,
                                URL [] extensionJarAndDllUrls,
                                String [] applicationPackages,
                                File cacheFolder,
                                String cachedFilesPrefix) {
-    this(parent, protectionDomain, extensionJarAndDllResources, extensionJarAndDllUrls, applicationPackages, 
+    this(parent, protectionDomain, extensionJarAndDllResources, extensionJarAndDllUrls, applicationPackages,
         cacheFolder, cachedFilesPrefix, false);
   }
 
   /**
    * Creates a class loader. It will consider JARs and DLLs of <code>extensionJarAndDllResources</code>
-   * and <code>extensionJarAndDllUrls</code> as classpath and libclasspath elements with a higher priority 
-   * than the ones of default classpath, and will load itself all the classes belonging to packages of 
+   * and <code>extensionJarAndDllUrls</code> as classpath and libclasspath elements with a higher priority
+   * than the ones of default classpath, and will load itself all the classes belonging to packages of
    * <code>applicationPackages</code>.<br>
-   * Copies of <code>extensionJarAndDllResources</code> and <code>extensionJarAndDllUrls</code> will be stored 
+   * Copies of <code>extensionJarAndDllResources</code> and <code>extensionJarAndDllUrls</code> will be stored
    * in the given cache folder if possible, each file being prefixed by <code>cachedFilesPrefix</code>.
    */
-  public ExtensionsClassLoader(ClassLoader parent, 
-                               ProtectionDomain protectionDomain, 
+  public ExtensionsClassLoader(ClassLoader parent,
+                               ProtectionDomain protectionDomain,
                                String [] extensionJarAndDllResources,
                                URL [] extensionJarAndDllUrls,
                                String [] applicationPackages,
@@ -107,19 +107,19 @@ public class ExtensionsClassLoader extends ClassLoader {
     // Compute DLLs prefix and suffix
     String dllSuffix;
     String dllPrefix;
-    
+
     String osName = System.getProperty("os.name");
     if (osName.startsWith("Windows")) {
-      dllSuffix = ".dll";
+      dllSuffix = ".+\\.dll$";
       dllPrefix = "";
     } else if (osName.startsWith("Mac OS X")) {
-      dllSuffix = ".jnilib";
+      dllSuffix = ".+\\.(jnilib|dylib)$";
       dllPrefix = "lib";
     } else {
-      dllSuffix = ".so";
+      dllSuffix = ".+\\.so$";
       dllPrefix = "lib";
     }
-    
+
     // Create a list containing only URLs
     ArrayList extensionJarsAndDlls = new ArrayList();
     for (int i = 0; i < extensionJarAndDllResources.length; i++) {
@@ -131,7 +131,7 @@ public class ExtensionsClassLoader extends ClassLoader {
     if (extensionJarAndDllUrls != null) {
       extensionJarsAndDlls.addAll(Arrays.asList(extensionJarAndDllUrls));
     }
-    
+
     // Find extension Jars and DLLs
     ArrayList extensionJars = new ArrayList();
     for (int i = 0; i < extensionJarsAndDlls.size(); i++) {
@@ -145,8 +145,8 @@ public class ExtensionsClassLoader extends ClassLoader {
         if (extensionJarOrDllUrl.getProtocol().equals("jar")) {
           // Don't instantiate connection to a file accessed by jar protocol otherwise it might download again its jar container
           URL jarEntryUrl = new URL(extensionJarOrDllUrlFile.substring(0, extensionJarOrDllUrlFile.indexOf('!')));
-          URLConnection jarEntryUrlConnection = jarEntryUrl.openConnection(); 
-          // connection.getLastModified() on an entry returns get modification date of the jar file itself 
+          URLConnection jarEntryUrlConnection = jarEntryUrl.openConnection();
+          // connection.getLastModified() on an entry returns get modification date of the jar file itself
           extensionJarOrDllFileDate = jarEntryUrlConnection.getLastModified();
           extensionJarOrDllFileLength = jarEntryUrlConnection.getContentLength();
           extensionJarOrDllFile = extensionJarOrDllUrlFile.substring(extensionJarOrDllUrlFile.indexOf('!') + 2);
@@ -161,15 +161,15 @@ public class ExtensionsClassLoader extends ClassLoader {
         boolean extensionJarFile = extensionJarOrDllFile.endsWith(".jar");
         if (extensionJarFile) {
           libraryName = null;
-        } else if (extensionJarOrDllFile.endsWith(dllSuffix)) {
+        } else if (extensionJarOrDllFile.matches(dllSuffix)) {
           libraryName = extensionJarOrDllFile.substring(lastSlashIndex + 1 + dllPrefix.length(),
-              extensionJarOrDllFile.length() - dllSuffix.length()); 
+              extensionJarOrDllFile.lastIndexOf('.'));
         } else {
           // Ignore DLLs of other platforms
           continue;
         }
-        
-        if (cacheFolder != null 
+
+        if (cacheFolder != null
             && (!cacheOnlyJars || extensionJarFile)
             && extensionJarOrDllFileDate != 0
             && extensionJarOrDllFileLength != -1
@@ -181,8 +181,8 @@ public class ExtensionsClassLoader extends ClassLoader {
                 + extensionJarOrDllFileLength + "-"
                 + (extensionJarOrDllFileDate / 1000L) + "-"
                 + extensionJarOrDllFile.replace('/', '-');
-            File cachedFile = new File(cacheFolder, extensionJarOrDllFileName);            
-            if (!cachedFile.exists() 
+            File cachedFile = new File(cacheFolder, extensionJarOrDllFileName);
+            if (!cachedFile.exists()
                 || cachedFile.lastModified() < extensionJarOrDllFileDate) {
               // Copy jar to cache
               if (connection == null) {
@@ -193,46 +193,47 @@ public class ExtensionsClassLoader extends ClassLoader {
             if (extensionJarFile) {
               // Add tmp file to extension jars list
               extensionJars.add(new JarFile(cachedFile.toString(), false));
-            } else if (extensionJarOrDllFile.endsWith(dllSuffix)) {
+            } else if (extensionJarOrDllFile.matches(dllSuffix)) {
               // Add tmp file to extension DLLs map
               this.extensionDlls.put(libraryName, cachedFile.toString());
             }
             continue;
           } catch (IOException ex) {
             // Try without cache
-          }          
-        } 
-        
+          }
+        }
+
         if (connection == null) {
           connection = extensionJarOrDllUrl.openConnection();
         }
-        InputStream input = connection.getInputStream();          
+        InputStream input = connection.getInputStream();
         if (extensionJarFile) {
           // Copy jar to a tmp file
           String extensionJar = copyInputStreamToTmpFile(input, ".jar");
           // Add tmp file to extension jars list
           extensionJars.add(new JarFile(extensionJar, false));
-        } else if (extensionJarOrDllFile.endsWith(dllSuffix)) {
+        } else if (extensionJarOrDllFile.matches(dllSuffix)) {
           // Copy DLL to a tmp file
-          String extensionDll = copyInputStreamToTmpFile(input, dllSuffix);
+          String extensionDll = copyInputStreamToTmpFile(input,
+              extensionJarOrDllFile.substring(extensionJarOrDllFile.lastIndexOf('.')));
           // Add tmp file to extension DLLs map
           this.extensionDlls.put(libraryName, extensionDll);
-        }          
+        }
       } catch (IOException ex) {
         throw new RuntimeException("Couldn't extract extension " + extensionJarOrDllUrl, ex);
       }
     }
-    
+
     // Create extensionJars array
     if (extensionJars.size() > 0) {
-      this.extensionJars = (JarFile [])extensionJars.toArray(new JarFile [extensionJars.size()]);                    
+      this.extensionJars = (JarFile [])extensionJars.toArray(new JarFile [extensionJars.size()]);
     }
   }
 
   /**
    * Returns the file name of a temporary copy of <code>input</code> content.
    */
-  private String copyInputStreamToTmpFile(InputStream input, 
+  private String copyInputStreamToTmpFile(InputStream input,
                                           String suffix) throws IOException {
     File tmpFile = File.createTempFile("extension", suffix);
     tmpFile.deleteOnExit();
@@ -248,7 +249,7 @@ public class ExtensionsClassLoader extends ClassLoader {
     try {
       output = new BufferedOutputStream(new FileOutputStream(file));
       byte [] buffer = new byte [8192];
-      int size; 
+      int size;
       while ((size = input.read(buffer)) != -1) {
         output.write(buffer, 0, size);
       }
@@ -261,13 +262,13 @@ public class ExtensionsClassLoader extends ClassLoader {
       }
     }
   }
-  
+
   /**
-   * Finds and defines the given class among the extension JARs  
-   * given in constructor, then among resources. 
+   * Finds and defines the given class among the extension JARs
+   * given in constructor, then among resources.
    */
   protected Class findClass(String name) throws ClassNotFoundException {
-    // Build class file from its name 
+    // Build class file from its name
     String classFile = name.replace('.', '/') + ".class";
     InputStream classInputStream = null;
     if (this.extensionJars != null) {
@@ -284,7 +285,7 @@ public class ExtensionsClassLoader extends ClassLoader {
         }
       }
     }
-    // If it's not an extension class, search if its an application 
+    // If it's not an extension class, search if its an application
     // class that can be read from resources
     if (classInputStream == null) {
       URL url = getResource(classFile);
@@ -296,43 +297,43 @@ public class ExtensionsClassLoader extends ClassLoader {
       } catch (IOException ex) {
         throw new ClassNotFoundException("Couldn't read class " + name, ex);
       }
-    } 
-    
+    }
+
     try {
       // Read class input content to a byte array
       ByteArrayOutputStream out = new ByteArrayOutputStream();
       BufferedInputStream in = new BufferedInputStream(classInputStream);
       byte [] buffer = new byte [8192];
-      int size; 
+      int size;
       while ((size = in.read(buffer)) != -1) {
         out.write(buffer, 0, size);
       }
       in.close();
       // Define class
-      return defineClass(name, out.toByteArray(), 0, out.size(), 
+      return defineClass(name, out.toByteArray(), 0, out.size(),
           this.protectionDomain);
     } catch (IOException ex) {
       throw new ClassNotFoundException("Class " + name, ex);
     }
   }
-  
+
   /**
    * Returns the library path of an extension DLL.
    */
   protected String findLibrary(String libname) {
     return (String)this.extensionDlls.get(libname);
   }
-  
+
   /**
-   * Returns the URL of the given resource searching first if it exists among 
-   * the extension JARs given in constructor. 
+   * Returns the URL of the given resource searching first if it exists among
+   * the extension JARs given in constructor.
    */
   protected URL findResource(String name) {
     if (this.extensionJars != null) {
       // Try to find if resource belongs to one of the extracted jars
       for (int i = 0; i < this.extensionJars.length; i++) {
         JarFile extensionJar = this.extensionJars [i];
-        JarEntry jarEntry = extensionJar.getJarEntry(name);        
+        JarEntry jarEntry = extensionJar.getJarEntry(name);
         if (jarEntry != null) {
           try {
             return new URL("jar:file:" + extensionJar.getName() + "!/" + jarEntry.getName());
@@ -363,7 +364,7 @@ public class ExtensionsClassLoader extends ClassLoader {
         for (int i = 0; i < this.applicationPackages.length; i++) {
           String applicationPackage = this.applicationPackages [i];
           int applicationPackageLength = applicationPackage.length();
-          if (   (applicationPackageLength == 0 
+          if (   (applicationPackageLength == 0
                  && name.indexOf('.') == 0)
               || (applicationPackageLength > 0
                  && name.startsWith(applicationPackage))) {
